@@ -32,7 +32,7 @@ class DBConnect:
                 Path to db_config.json.
                 Defaults to file in same directory as this script.
         """
-        self._version = "v2.4.1"
+        self._version = "v2.5.1"
         self.config_file_path = (
             os.path.join(os.path.dirname(__file__), "db_config.json")
             if config_file_path is None
@@ -57,6 +57,10 @@ class DBConnect:
     def file_reader(self):
         """Create and return a FileReader instance."""
         return self.FileReader()
+    
+    def geodatabase_reader(self):
+        """Create and return a GDBReader instance."""
+        return self.GDBReader()
 
     def data_dumper(self, connection, engine):
         """Create and return a DataDumper instance."""
@@ -262,31 +266,26 @@ class DBConnect:
 
     class FileReader:
         """
-        Read supported file formats into Pandas or GeoPandas DataFrames and
-        provide utilities for File Geodatabases (.gdb, .gdb.zip).
+        Read common tabular and vector file formats into Pandas/GeoPandas.
 
         Supported formats:
         - .csv
         - .shp, .geojson
         - .xlsx, .xlsm, .xls, .xlsb (requires sheet name)
-        - .gdb (directory) and .gdb.zip (zip containing a .gdb folder)
         """
 
-        # ---------- Public API ----------
-
         def read_file(
             self,
             file_path: str,
             file_sheetname: Optional[str] = None,
-            file_layer: Optional[str] = None,
+            file_layer: Optional[str] = None,  # kept for API compatibility; ignored
         ) -> Union[pd.DataFrame, gpd.GeoDataFrame]:
             """
-            Read various geospatial and tabular file types into a DataFrame.
+            Read a file into a DataFrame/GeoDataFrame.
 
             Args:
                 file_path: Full path to the file.
                 file_sheetname: Sheet name for Excel files.
-                file_layer: Layer name for GDB (optional; defaults to first layer).
 
             Returns:
                 pd.DataFrame or gpd.GeoDataFrame
@@ -298,10 +297,6 @@ class DBConnect:
             file = os.path.basename(file_path)
             ext = os.path.splitext(file)[1].lower()
 
-            # Geodatabase handling (directory .gdb or zipped .gdb.zip)
-            if self._is_gdb_path(file_path):
-                return self._read_gdb(file_path, file_layer)
-
             match ext:
                 case ".shp" | ".geojson":
                     return gpd.read_file(file_path)
@@ -312,110 +307,85 @@ class DBConnect:
                         raise ValueError(f"Sheet name must be provided for Excel file: {file}")
                     return pd.read_excel(file_path, sheet_name=file_sheetname)
                 case ".zip":
-                    # Only supported zip flavor is .gdb.zip (caught above)
                     raise ValueError(f"Unsupported .zip content: {file}")
                 case _:
                     raise ValueError(f"Unsupported file type: {ext}")
+    
+    
+    class GDBReader:
+        """
+        Minimal Esri File Geodatabase reader.
+
+        - Supports .gdb directories and .gdb.zip archives
+        - Reads entire layers as-is (no filters / reprojection)
+        - Always prefers pyogrio for speed; falls back to GeoPandas/Fiona
+        """
+
+        # ---------- Public API ----------
 
         def get_layers(self, gdb_path: str) -> List[str]:
-            """
-            List layers in a File Geodatabase (.gdb or .gdb.zip).
-
-            Args:
-                gdb_path: Path to .gdb directory or .gdb.zip file.
-
-            Returns:
-                List of layer names.
-
-            Raises:
-                ValueError: If not a valid GDB or no layers found.
-            """
-            vfs = self._resolve_vfs_path(gdb_path)
+            """Return all layer names inside a .gdb or .gdb.zip."""
+            vfs = self._resolve_path(gdb_path)
             layers = list(fiona.listlayers(vfs))
             if not layers:
-                raise ValueError("No layers found in the geodatabase.")
+                raise ValueError(f"No layers found in: {gdb_path}")
             return layers
 
+        def read_layer(self, gdb_path: str, layer_name: Optional[str] = None) -> gpd.GeoDataFrame:
+            """
+            Read a full layer into a GeoDataFrame.
+            If layer_name is None, reads the first available layer.
+            """
+            vfs = self._resolve_path(gdb_path)
+            layers = self.get_layers(gdb_path)
+            target = layer_name or layers[0]
+            if target not in layers:
+                raise ValueError(f"Layer '{target}' not found. Available: {layers}")
+
+            # Fast path: pyogrio
+            try:
+                import pyogrio  # type: ignore
+                return pyogrio.read_dataframe(vfs, layer=target)
+            except Exception:
+                # Fallback: GeoPandas/Fiona
+                return gpd.read_file(vfs, layer=target)
+
         def layer_statistics(self, gdb_path: str, layer_name: str) -> Dict[str, object]:
             """
-            Compute simple stats for a geodatabase layer.
-
-            Args:
-                gdb_path: Path to .gdb directory or .gdb.zip.
-                layer_name: Layer to inspect.
-
-            Returns:
-                Dict with basic stats.
+            Quick metadata without loading all features into memory.
             """
-            gdf = self._read_gdb_layer(gdb_path, layer_name)
-            return {
-                "gdb_path": os.path.abspath(gdb_path),
-                "layer": layer_name,
-                "rows": int(len(gdf)),
-                "columns": list(gdf.columns),
-                "geometry_type": sorted({str(t) for t in gdf.geom_type.unique()}),
-                "crs": str(gdf.crs),
-                "bounds": tuple(map(float, gdf.total_bounds)) if not gdf.empty else None,  # (minx, miny, maxx, maxy)
-                "null_counts": gdf.isna().sum().to_dict(),
-            }
-        
-        def read_gdb_layer(self, gdb_path: str, layer_name: str) -> gpd.GeoDataFrame:
-            """
-            Public method to read a specific GDB layer into a GeoDataFrame.
+            vfs = self._resolve_path(gdb_path)
+            if layer_name not in fiona.listlayers(vfs):
+                raise ValueError(f"Layer '{layer_name}' not found in: {gdb_path}")
+            with fiona.open(vfs, layer=layer_name) as src:
+                return {
+                    "gdb_path": os.path.abspath(gdb_path),
+                    "layer": layer_name,
+                    "feature_count": int(len(src)),
+                    "geometry_type": src.schema.get("geometry"),
+                    "properties": list(src.schema.get("properties", {}).keys()),
+                    "crs": str(src.crs) if src.crs else None,
+                    "bounds": tuple(map(float, src.bounds)) if src.bounds else None,
+                }
 
-            Args:
-                gdb_path: Path to .gdb directory or .gdb.zip.
-                layer_name: Exact layer name (see `get_layers`).
-
-            Returns:
-                GeoDataFrame for the requested layer.
-
-            Raises:
-                ValueError: If path is not a GDB or layer does not exist.
-            """
-            return self._read_gdb_layer(gdb_path, layer_name)
-
-        # ---------- Internal helpers ----------
+        # ---------- Internals ----------
 
         @staticmethod
-        def _is_gdb_path(path: str) -> bool:
-            p = path.lower()
-            return p.endswith(".gdb") or p.endswith(".gdb.zip")
-
-        @staticmethod
-        def _resolve_vfs_path(path: str) -> str:
+        def _resolve_path(path: str) -> str:
             """
-            Return path usable by fiona/geopandas:
-            - '/abs/path/to/file.gdb' for directory geodatabases
-            - '/vsizip/abs/path/to/file.gdb.zip/file.gdb' for zipped geodatabases
+            Normalize to a GDAL-readable path:
+            - '/abs/path/to/file.gdb' for directories
+            - '/vsizip/abs/path/to/file.gdb.zip/file.gdb' for zipped archives
             """
             abs_path = os.path.abspath(path)
             lower = abs_path.lower()
+            if lower.endswith(".gdb"):
+                return abs_path
             if lower.endswith(".gdb.zip"):
                 gdb_name = os.path.basename(abs_path).replace(".zip", "")
                 return f"/vsizip/{abs_path}/{gdb_name}"
-            if lower.endswith(".gdb"):
-                return abs_path
-            raise ValueError("Not a geodatabase path (.gdb or .gdb.zip).")
-
-        def _read_gdb(self, gdb_path: str, layer: Optional[str]) -> gpd.GeoDataFrame:
-            vfs = self._resolve_vfs_path(gdb_path)
-            layers = list(fiona.listlayers(vfs))
-            if not layers:
-                raise ValueError(f"No layers found in geodatabase: {gdb_path}")
-
-            layer_to_read = layer or layers[0]
-            if layer_to_read not in layers:
-                raise ValueError(f"Layer '{layer_to_read}' not found. Available: {layers}")
-
-            return gpd.read_file(vfs, layer=layer_to_read)
-
-        def _read_gdb_layer(self, gdb_path: str, layer: str) -> gpd.GeoDataFrame:
-            vfs = self._resolve_vfs_path(gdb_path)
-            # Light validation before read
-            if layer not in fiona.listlayers(vfs):
-                raise ValueError(f"Layer '{layer}' not found in: {gdb_path}")
-            return gpd.read_file(vfs, layer=layer)
+            raise ValueError("Path must end with .gdb or .gdb.zip")
+        
 
     class DataDumper:
         """
